@@ -12,17 +12,19 @@
 # limitations under the License.
 import requests
 
+from ubersmith_client import _http_utils
 from ubersmith_client.ubersmith_request import UbersmithRequest
 
 
 class UbersmithRequestPost(UbersmithRequest):
     def __call__(self, **kwargs):
         self._build_request_params(kwargs)
+        params = _http_utils.form_encode(kwargs)
 
         response = self._process_request(method=requests.post,
                                          url=self.url,
                                          auth=(self.user, self.password),
                                          timeout=self.timeout,
-                                         data=kwargs)
+                                         data=params)
 
         return UbersmithRequest.process_ubersmith_response(response)
